# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: logger/v1/logger.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'logger/v1/logger.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16logger/v1/logger.proto\x12\tlogger.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"&\n\x03\x41\x63k\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xfc\x01\n\x10\x43reateRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0b\x63onfig_json\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05notes\x18\x08 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x65ntity\x18\t \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x08\n\x06_notesB\t\n\x07_entity\"\xbf\x01\n\x06Record\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cpayload_json\x18\x02 \x01(\t\x12\x19\n\x0cpayload_name\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08sequence\x18\x04 \x01(\x03H\x01\x88\x01\x01\x12\x14\n\x07runtime\x18\x05 \x01(\x02H\x02\x88\x01\x01\x42\x0f\n\r_payload_nameB\x0b\n\t_sequenceB\n\n\x08_runtime\"l\n\x17StoreRecordBatchRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\"\n\x07records\x18\x04 \x03(\x0b\x32\x11.logger.v1.Record2\x91\x01\n\rLoggerService\x12\x38\n\tCreateRun\x12\x1b.logger.v1.CreateRunRequest\x1a\x0e.logger.v1.Ack\x12\x46\n\x10StoreRecordBatch\x12\".logger.v1.StoreRecordBatchRequest\x1a\x0e.logger.v1.AckB3Z1macrocosm-os/rift/constellation_api/gen/logger/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'logger.v1.logger_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1macrocosm-os/rift/constellation_api/gen/logger/v1'
  _globals['_ACK']._serialized_start=70
  _globals['_ACK']._serialized_end=108
  _globals['_CREATERUNREQUEST']._serialized_start=111
  _globals['_CREATERUNREQUEST']._serialized_end=363
  _globals['_RECORD']._serialized_start=366
  _globals['_RECORD']._serialized_end=557
  _globals['_STORERECORDBATCHREQUEST']._serialized_start=559
  _globals['_STORERECORDBATCHREQUEST']._serialized_end=667
  _globals['_LOGGERSERVICE']._serialized_start=670
  _globals['_LOGGERSERVICE']._serialized_end=815
# @@protoc_insertion_point(module_scope)
